@@ -5,9 +5,15 @@ from bs4 import BeautifulSoup
 def extract_article(article_url: str)-> bs4.element.Tag:
     """Extracts data from given ceo news url"""
     r = requests.get(article_url)
+    if r == None:
+        print('No data returned from the url')
+        print('need more delay???')
     data = r.text
     soup = BeautifulSoup(data, features="html.parser")
-    scripts = [x.extract() for x in soup.findAll('script')]
+    try:
+        scripts = [x.extract() for x in soup.findAll('script')]
+    except AttributeError as e:
+        print('No Scripts to Extract from article')
     # print(soup.prettify())
     article = soup.find(attrs={'class': 'article-body article'})
     # Use this as a example
